@@ -1,20 +1,18 @@
 import logging
 from collections import defaultdict
-from typing import Dict, List, Optional
+from typing import List, Optional
 
 import ujson
-from twisted.internet.defer import inlineCallbacks
 from vortex.DeferUtil import deferToThreadWrapWithLogger
 from vortex.Payload import Payload
 
+from peek_abstract_chunked_index.private.client.controller.ACICacheControllerABC import \
+    ACICacheControllerABC
 from peek_core_search._private.PluginNames import searchFilt
 from peek_core_search._private.server.client_handlers.ClientChunkLoadRpc import \
     ClientChunkLoadRpc
 from peek_core_search._private.storage.EncodedSearchObjectChunk import \
     EncodedSearchObjectChunk
-from vortex.PayloadEndpoint import PayloadEndpoint
-from vortex.PayloadEnvelope import PayloadEnvelope
-
 from peek_core_search._private.storage.SearchObjectTypeTuple import SearchObjectTypeTuple
 from peek_core_search._private.tuples.search_object.SearchResultObjectRouteTuple import \
     SearchResultObjectRouteTuple
@@ -28,7 +26,7 @@ clientSearchObjectUpdateFromServerFilt = dict(key="clientSearchObjectUpdateFromS
 clientSearchObjectUpdateFromServerFilt.update(searchFilt)
 
 
-class SearchObjectCacheController:
+class SearchObjectCacheController(ACICacheControllerABC):
     """ SearchObject Cache Controller
 
     The SearchObject cache controller stores all the chunks in memory,
@@ -36,78 +34,10 @@ class SearchObjectCacheController:
 
     """
 
-    LOAD_CHUNK = 32
-
-    def __init__(self, clientId: str):
-        self._clientId = clientId
-        self._webAppHandler = None
-
-        #: This stores the cache of searchObject data for the clients
-        self._cache: Dict[int, EncodedSearchObjectChunk] = {}
-
-        self._endpoint = PayloadEndpoint(clientSearchObjectUpdateFromServerFilt,
-                                         self._processSearchObjectPayload)
-
-    def setSearchObjectCacheHandler(self, handler):
-        self._webAppHandler = handler
-
-    @inlineCallbacks
-    def start(self):
-        yield self.reloadCache()
-
-    def shutdown(self):
-        self._tupleObservable = None
-
-        self._endpoint.shutdown()
-        self._endpoint = None
-
-        self._cache = {}
-
-    @inlineCallbacks
-    def reloadCache(self):
-        self._cache = {}
-
-        offset = 0
-        while True:
-            logger.info(
-                "Loading SearchObjectChunk %s to %s" % (offset, offset + self.LOAD_CHUNK))
-            encodedChunkTuples: List[EncodedSearchObjectChunk] = (
-                yield ClientChunkLoadRpc.loadSearchObjectChunks(offset, self.LOAD_CHUNK)
-            )
-
-            if not encodedChunkTuples:
-                break
-
-            self._loadSearchObjectIntoCache(encodedChunkTuples)
-
-            offset += self.LOAD_CHUNK
-
-    @inlineCallbacks
-    def _processSearchObjectPayload(self, payloadEnvelope: PayloadEnvelope, **kwargs):
-        paylod = yield payloadEnvelope.decodePayloadDefer()
-        searchObjectTuples: List[EncodedSearchObjectChunk] = paylod.tuples
-        self._loadSearchObjectIntoCache(searchObjectTuples)
-
-    def _loadSearchObjectIntoCache(self,
-                                   encodedChunkTuples: List[EncodedSearchObjectChunk]):
-        chunkKeysUpdated: List[str] = []
-
-        for t in encodedChunkTuples:
-
-            if (not t.chunkKey in self._cache or
-                    self._cache[t.chunkKey].lastUpdate != t.lastUpdate):
-                self._cache[t.chunkKey] = t
-                chunkKeysUpdated.append(t.chunkKey)
-
-        logger.debug("Received searchObject updates from server, %s", chunkKeysUpdated)
-
-        self._webAppHandler.notifyOfSearchObjectUpdate(chunkKeysUpdated)
-
-    def searchObject(self, chunkKey) -> EncodedSearchObjectChunk:
-        return self._cache.get(chunkKey)
-
-    def searchObjectKeys(self) -> List[int]:
-        return list(self._cache)
+    _ChunkedTuple = EncodedSearchObjectChunk
+    _chunkLoadRpcMethod = ClientChunkLoadRpc.loadSearchObjectChunks
+    _updateFromServerFilt = clientSearchObjectUpdateFromServerFilt
+    _logger = logger
 
     @deferToThreadWrapWithLogger(logger)
     def getObjects(self, objectTypeId: Optional[int],
@@ -134,7 +64,7 @@ class SearchObjectCacheController:
                                     objectIds: List[int]
                                     ) -> List[SearchResultObjectTuple]:
 
-        chunk = self.searchObject(chunkKey)
+        chunk = self.encodedChunk(chunkKey)
         if not chunk:
             return []
 
